@@ -1,3 +1,4 @@
+import collections
 import functools
 import itertools
 
@@ -11,6 +12,8 @@ from .plot_specs import (
 )
 from .utils import auto_label, call_or_eval, RunManager, run_is_live_and_not_completed
 from ..utils.dict_view import DictView
+from ..utils.event import EmitterGroup, Event
+from ..utils.list import EventedList
 
 
 class Lines:
@@ -156,24 +159,15 @@ class Lines:
         if label_maker is None:
             # scan_id is always generated by RunEngine but not stricter required by
             # the schema, so we fail gracefully if it is missing.
-
-            if len(ys) > 1:
-
-                def label_maker(run, y):
-                    return (
-                        f"Scan {run.metadata['start'].get('scan_id', '?')} "
-                        f"{auto_label(y)}"
-                    )
-
-            else:
-
-                def label_maker(run, y):
-                    return f"Scan {run.metadata['start'].get('scan_id', '?')}"
+            def label_maker(run, y):
+                return f"Scan {run.metadata['start'].get('scan_id', '?')} {auto_label(y)}"
 
         self._x = x
         if isinstance(ys, str):
             raise ValueError("`ys` must be a list of strings, not a string")
-        self._ys = tuple(ys)
+        self._ys = EventedList(ys)
+        # Maps ys to set of ArtistSpec.
+        self._ys_to_artists = collections.defaultdict(list)
         self._label_maker = label_maker
         self._namespace = namespace
         if axes is None:
@@ -181,10 +175,16 @@ class Lines:
                 x_label=auto_label(self.x),
                 y_label=", ".join(auto_label(y) for y in self.ys),
             )
-            figure = Figure((axes,), title=f"{axes.y_label} v {axes.x_label}")
+            figure = Figure((axes,), title="")
         else:
             figure = axes.figure
         self.axes = axes
+        if self.axes.x_label is None:
+            self.axes.x_label = auto_label(self.x)
+        if self.axes.y_label is None:
+            self.axes.y_label = self._default_y_label()
+        if self.axes.title is None:
+            self.axes.title = self._default_title()
         self.figure = figure
         # If the Axes' figure is not yet set, listen for it to be set.
         if figure is None:
@@ -196,18 +196,42 @@ class Lines:
 
             self.axes.events.figure.connect(set_figure)
 
+        # Keep title up to date with self.ys or leave it as user-defined value
+        self._control_title = self.axes.title == self._default_title()
+        # Keep y_label up to date with self.ys or leave it as user-defined value
+        self._control_y_label = self.axes.y_label == self._default_y_label()
+
         self._color_cycle = itertools.cycle(f"C{i}" for i in range(10))
 
         self._run_manager = RunManager(max_runs, needs_streams)
         self._run_manager.events.run_ready.connect(self._add_lines)
         self.add_run = self._run_manager.add_run
         self.discard_run = self._run_manager.discard_run
+        self.events = EmitterGroup(
+            source=self,
+            title=Event,
+            y_label=Event,
+        )
+
+        self.ys.events.added.connect(self._add_ys)
+        self.ys.events.removed.connect(self._remove_ys)
+
+    def _default_y_label(self):
+        return ", ".join(auto_label(y) for y in self.ys)
+
+    def _default_title(self):
+        return f"{self._default_y_label()} v {self.axes.x_label}"
 
     def _transform(self, run, x, y):
         return call_or_eval({"x": x, "y": y}, run, self.needs_streams, self.namespace)
 
     def _add_lines(self, event):
         "Add a line."
+        if self._control_y_label:
+            self.y_label = self._default_y_label()
+        if self._control_title:
+            self.title = self._default_title()
+
         run = event.run
         for y in self.ys:
             label = self._label_maker(run, y)
@@ -233,6 +257,53 @@ class Lines:
             line = Line.from_run(func, run, label, style)
             self._run_manager.track_artist(line, [run])
             self.axes.artists.append(line)
+            self._ys_to_artists[y].append(line)
+
+    def _add_ys(self, event):
+        "Add a y."
+        # Update title and y_label when adding a new y
+        if self._control_y_label:
+            self.y_label = self._default_y_label()
+        if self._control_title:
+            self.title = self._default_title()
+
+        y = event.item
+        for run in self._run_manager.runs:
+            label = self._label_maker(run, y)
+            # If run is in progress, give it a special color so it stands out.
+            if run_is_live_and_not_completed(run):
+                color = "black"
+
+                def restyle_line_when_complete(event):
+                    "When run is complete, update style."
+                    line.style.update({"color": next(self._color_cycle)})
+
+                run.events.completed.connect(restyle_line_when_complete)
+            else:
+                color = next(self._color_cycle)
+            style = {"color": color}
+
+            # Style pinned runs differently.
+            if run.metadata["start"]["uid"] in self.pinned:
+                style.update(linestyle="dashed")
+                label += " (pinned)"
+
+            func = functools.partial(self._transform, x=self.x, y=y)
+            line = Line.from_run(func, run, label, style)
+            self._run_manager.track_artist(line, [run])
+            self.axes.artists.append(line)
+            self._ys_to_artists[y].append(line)
+
+    def _remove_ys(self, event):
+        "Remove a y."
+        # Update title and y_label when removing a y
+        if self._control_y_label:
+            self.y_label = self._default_y_label()
+        if self._control_title:
+            self.title = self._default_title()
+        y = event.item
+        for artist in self._ys_to_artists.pop(y):
+            artist.axes.discard(artist)
 
     @property
     def x(self):
@@ -268,6 +339,40 @@ class Lines:
     def pinned(self):
         return self._run_manager._pinned
 
+    # Expose axes title and y_label
+
+    @property
+    def title(self):
+        return self.axes.title
+
+    @title.setter
+    def title(self, value):
+        if value is None or value == self._default_title():
+            self._control_title = True
+            value = self._default_title()
+        else:
+            # Title has been set to something specific.
+            # Don't sync it with self.ys
+            self._control_title = False
+        self.axes.title = value
+        self.events.title(value=value)
+
+    @property
+    def y_label(self):
+        return self.axes.y_label
+
+    @y_label.setter
+    def y_label(self, value):
+        if value is None or value == self._default_y_label():
+            self._control_y_label = True
+            value = self._default_y_label()
+        else:
+            # y_label has been set to something specific.
+            # Don't sync it with self.ys
+            self._control_y_label = False
+        self.axes.y_label = value
+        self.events.y_label(value=value)
+
 
 class Images:
     """
@@ -345,10 +450,7 @@ class Images:
 
             def label_maker(run, field):
                 md = run.metadata["start"]
-                return (
-                    f"Scan ID {md.get('scan_id', '?')}   UID {md['uid'][:8]}   "
-                    f"{auto_label(field)}"
-                )
+                return f"Scan ID {md.get('scan_id', '?')}   UID {md['uid'][:8]}   " f"{auto_label(field)}"
 
         self._field = field
         self._label_maker = label_maker
@@ -390,6 +492,10 @@ class Images:
         # axis until there are only two axes.
         data = result["array"]
         while data.ndim > 2:
+            if data.shape[0] == 0:
+                # Handle case where array is just initialized, with a shape like (0, y, x).
+                data = numpy.zeros(data.shape[1:])
+                continue
             middle = data.shape[0] // 2
             data = data[middle]
         result["array"] = data
@@ -507,9 +613,7 @@ class RasteredImages:
 
             def label_maker(run, field):
                 md = run.metadata["start"]
-                return (
-                    f"Scan ID {md.get('scan_id', '?')}   UID {md['uid'][:8]}   {field}"
-                )
+                return f"Scan ID {md.get('scan_id', '?')}   UID {md['uid'][:8]}   {field}"
 
         self._label_maker = label_maker
 
@@ -595,13 +699,9 @@ class RasteredImages:
             raise ValueError('x_positive must be "right" or "left"')
         self._x_positive = value
         xmin, xmax = self.axes.x_limits
-        if (xmin > xmax and self._x_positive == "right") or (
-            xmax > xmin and self._x_positive == "left"
-        ):
+        if (xmin > xmax and self._x_positive == "right") or (xmax > xmin and self._x_positive == "left"):
             self.axes.x_limits = (xmax, xmin)
-        elif (xmax >= xmin and self._x_positive == "right") or (
-            xmin >= xmax and self._x_positive == "left"
-        ):
+        elif (xmax >= xmin and self._x_positive == "right") or (xmin >= xmax and self._x_positive == "left"):
             self.axes.x_limits = (xmin, xmax)
             self._x_positive = value
 
@@ -620,13 +720,9 @@ class RasteredImages:
             raise ValueError('y_positive must be "up" or "down"')
         self._y_positive = value
         ymin, ymax = self.axes.y_limits
-        if (ymin > ymax and self._y_positive == "up") or (
-            ymax > ymin and self._y_positive == "down"
-        ):
+        if (ymin > ymax and self._y_positive == "up") or (ymax > ymin and self._y_positive == "down"):
             self.axes.y_limits = (ymax, ymin)
-        elif (ymax >= ymin and self._y_positive == "up") or (
-            ymin >= ymax and self._y_positive == "down"
-        ):
+        elif (ymax >= ymin and self._y_positive == "up") or (ymin >= ymax and self._y_positive == "down"):
             self.axes.y_limits = (ymin, ymax)
             self._y_positive = value
 
